#! /bin/sh

ROOT_DIR="/ltu"
NAME="Network UPS Tools"

export PATH="$ROOT_DIR/bin:$ROOT_DIR/sbin:$PATH"
export LD_LIBRARY_PATH="$ROOT_DIR/lib"

func_start()
{
	# Make sure already running
	if [ -n "`pidof upsmon`" ] || [ -n "`pidof upsd`" ]  ; then
		echo "$NAME already running!"
		return 0
	fi
	
	nutconfig="$ROOT_DIR/etc/nut/nut.conf"
	
	# Load NUT nut.conf
	. "$nutconfig"
	
	# Explicitly require the configuration to be done in /etc/nut/nut.conf
	if [ "x$MODE" = "xnone" -o -z "$MODE" ] ; then
		echo "NUT disabled, please adjust the configuration to your needs"
		echo "Then set MODE to a suitable value in $nutconfig to enable it"
		return 0
	fi
	
	echo "Starting $NAME:"
	
	state_dir=/var/state/ups
	mkdir -p -m 770 "$state_dir"
	chown nobody "$state_dir"
	
	case "$MODE" in
	standalone|netserver)
		upsdrvctl start
		start-stop-daemon -S -c nobody -x upsd
		;;
	esac
	
	case "$MODE" in
	standalone|netserver|netclient)
		upsmon
		;;
	esac
	
	echo "Done."
}

func_stop()
{
	echo "Stopping $NAME:"
	
	killall -q upsmon
	killall -q upsd
	
	upsdrvctl stop 2>/dev/null
	
	echo "Done."
}

func_reload()
{
	upsd -c reload
	upsmon -c reload
}

case "$1" in
start)
	func_start
	;;
stop)
	func_stop
	;;
reload)
	func_reload
	;;
restart)
	func_stop
	sleep 1
	func_start
	;;
*)
	echo "Usage: $0 {start|stop|reload|restart}"
	exit 1
	;;
esac

exit 0
