#!/bin/sh

ltu_tar="dune-ltu-0.4.7.tar.gz"

if [ -z "`cat /proc/cpuinfo | grep 'MIPS 74K'`" ] ; then
	echo "ERROR: This package intended only for Sigma Design SMP864x CPU!"
	exit 1
fi

if [ ! -d /persistfs ] || ! mountpoint -q /persistfs ; then
	echo "ERROR: System storage (/persistfs) not installed!"
	echo "SOLUTION: Please create system storage first."
	exit 1
fi

if [ ! -f "$ltu_tar" ] ; then
	echo "ERROR: package file \"$ltu_tar\" not found!"
	exit 1
fi

if [ -x /persistfs/ltu/rc ] ; then
	echo -n "Stopping existing LTU: "
	/persistfs/ltu/rc stop >/dev/null 2>&1
	echo "[  OK  ]"
fi

# try to unbind system script (binded under build 0.2 and 0.1)
umount /firmware/scripts/reset_settings.sh 2>/dev/null

# delete old files
rm -f /persistfs/ltu/etc/aria2.conf
rm -f /persistfs/ltu/bin/aria2d
rm -f /persistfs/ltu/bin/mcmfmt
rm -f /persistfs/ltu/lib/libncurses.so
rm -f /persistfs/ltu/lib/libncurses.so.5
rm -f /persistfs/ltu/lib/libncurses.so.5.7
rm -f /persistfs/ltu/lib/libslang.so
rm -f /persistfs/ltu/lib/libslang.so.2
rm -f /persistfs/ltu/lib/libslang.so.2.2.2
rm -f /persistfs/ltu/lib/libevent.so
rm -f /persistfs/ltu/lib/libevent-1.4.so.2
rm -f /persistfs/ltu/lib/libevent-1.4.so.2.1.3
rm -f /persistfs/ltu/lib/libevent-2.0.so.5
rm -f /persistfs/ltu/lib/libevent-2.0.so.5.1.0
rm -f /persistfs/ltu/lib/libparted.so
rm -f /persistfs/ltu/lib/libparted.so.0
rm -f /persistfs/ltu/lib/libparted.so.0.0.1
rm -rf /persistfs/ltu/etc/mc
rm -rf /persistfs/ltu/lib/mc
rm -rf /persistfs/ltu/share/mc

echo -n "Extracting package: "
tar -xzf "$ltu_tar" -C /persistfs

if [ ! -f /persistfs/ltu/rc ] ; then
	echo "[FAILED]"
	echo "ERROR: unable to extract package to destination /persistfs/ltu!"
	exit 1
fi

echo "[  OK  ]"

echo -n "Configuring package: "

mkdir -p /persistfs/ltu/home

# remove old boot script
rm -f /persistfs/ltu/boot/ltu.sh

# update new home path
if [ -d /persistfs/ltu/var/.microdc2 ] ; then
	mv -f /persistfs/ltu/var/.microdc2 /persistfs/ltu/home
fi

if [ -f /persistfs/ltu/etc/microdc2/config ] ; then
	mv -f /persistfs/ltu/etc/microdc2/config /persistfs/ltu/etc/microdc2.conf
	rmdir /persistfs/ltu/etc/microdc2 2>/dev/null
fi

# create default conf files
[ ! -f /persistfs/ltu/etc/nut/nut.conf ] && cp /persistfs/ltu/etc/default/nut.conf /persistfs/ltu/etc/nut
[ ! -f /persistfs/ltu/etc/nut/ups.conf ] && cp /persistfs/ltu/etc/default/ups.conf /persistfs/ltu/etc/nut
[ ! -f /persistfs/ltu/etc/nut/upsd.conf ] && cp /persistfs/ltu/etc/default/upsd.conf /persistfs/ltu/etc/nut
[ ! -f /persistfs/ltu/etc/nut/upsd.users ] && cp /persistfs/ltu/etc/default/upsd.users /persistfs/ltu/etc/nut
[ ! -f /persistfs/ltu/etc/nut/upsmon.conf ] && cp /persistfs/ltu/etc/default/upsmon.conf /persistfs/ltu/etc/nut
[ ! -f /persistfs/ltu/etc/nut/upssched.conf ] && cp /persistfs/ltu/etc/default/upssched.conf /persistfs/ltu/etc/nut
[ ! -f /persistfs/ltu/etc/smartd.conf ] && cp /persistfs/ltu/etc/default/smartd.conf /persistfs/ltu/etc
[ ! -f /persistfs/ltu/etc/screenrc ] && cp /persistfs/ltu/etc/default/screenrc /persistfs/ltu/etc
[ ! -f /persistfs/ltu/etc/nanorc ] && cp /persistfs/ltu/etc/default/nanorc /persistfs/ltu/etc
[ ! -f /persistfs/ltu/etc/exports ] && cp /persistfs/ltu/etc/default/exports /persistfs/ltu/etc
[ ! -f /persistfs/ltu/etc/microdc2.conf ] && cp /persistfs/ltu/etc/default/microdc2.conf /persistfs/ltu/etc

# restrict access for nut
chown nobody /persistfs/ltu/etc/nut/ups.conf
chown nobody /persistfs/ltu/etc/nut/upsd.conf
chown nobody /persistfs/ltu/etc/nut/upsd.users
chown nobody /persistfs/ltu/etc/nut/upsmon.conf
chown nobody /persistfs/ltu/etc/nut/upssched.conf

# create default LTU configure
LOCALE_UTF8=1
SAVE_PASSWD=0
START_TELNET=1
START_SSH=0
START_NFSD=0
START_TRANSMISSION=0
START_DCPP=0
START_ARIA_RPC=0
START_NUT=0
START_SMARTD=0
USE_FTP_SERVER=1
USE_FIX_TCP_RMEM=0
HDD_SPINDOWN_TIME=30
HDD_APM_DISABLE=0
HDD_AAM_QUIET=0
[ -r /persistfs/ltu/configure ] && . /persistfs/ltu/configure

echo "
# select system locale (0=en_US.UTF-8, 1=ru_RU.UTF-8, 2=uk_UA.UTF-8)
LOCALE_UTF8=$LOCALE_UTF8

# store users, groups and passwords on system drive
SAVE_PASSWD=$SAVE_PASSWD

# start Telnet terminal server
START_TELNET=$START_TELNET

# start SSH terminal server (0=OFF, 1=Dropbear, 2=OpenSSH)
START_SSH=$START_SSH

# start NFS server
START_NFSD=$START_NFSD

# start bittorent transmission-daemon
START_TRANSMISSION=$START_TRANSMISSION

# start DC++ client microdc2 (as daemon via screen). Configure in /ltu/etc/microdc2.conf
START_DCPP=$START_DCPP

# start download manager aria2c as RPC server
START_ARIA_RPC=$START_ARIA_RPC

# start Network UPS Tools (NUT)
START_NUT=$START_NUT

# start smartd logger daemon (check interval 120 min)
START_SMARTD=$START_SMARTD

# select FTP server (0=disable FTP server, 1=use original vsftpd, 2=use secure Pure-FTPd server with virtual users database)
USE_FTP_SERVER=$USE_FTP_SERVER

# use fixed TCP receive window for prevent kernel crash (0=auto fix on start transmission/aria2/microdc2, 1=force fix on start LTU)
USE_FIX_TCP_RMEM=$USE_FIX_TCP_RMEM

# set HDD idle spindown time in minutes for HDD drives (0=not change, valid values 5/10/15/20/30/60/90/120/150/180 min)
HDD_SPINDOWN_TIME=$HDD_SPINDOWN_TIME

# disable HDD advanced power management for decrease Load_Cycle_Count (0=not change, 1=disable APM)
HDD_APM_DISABLE=$HDD_APM_DISABLE

# set HDD advanced acoustic management to quiet mode (0=not change, 1=AAM quiet)
HDD_AAM_QUIET=$HDD_AAM_QUIET" > /persistfs/ltu/configure

chmod 644 /persistfs/ltu/configure

echo "[  OK  ]"

echo -n "Installing package: "
/persistfs/ltu/rc install >/dev/null 2>&1

echo "[  OK  ]"

